NLSL: daxpy.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
daxpy.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | daxpy (n, da, dx, incx, dy, incy)

## Function/Subroutine Documentation

subroutine daxpy | ( | integer | n,
|  | double precision | da,
|  | double precision, dimension(1) | dx,
|  | integer | incx,
|  | double precision, dimension(1) | dy,
|  | integer | incy
| ) |  |

Definition at line 2 of file daxpy.f90.